@@ -5,6 +5,7 @@ mod cli;
 mod decoder;
 mod download;
 mod formatting;
+mod generation;
 mod middleware;
 mod nested_json;
 mod netrc;
@@ -15,11 +16,10 @@ mod request_items;
 mod session;
 mod to_curl;
 mod utils;
-mod vendored;
 
 use std::env;
 use std::fs::File;
-use std::io::{self, IsTerminal, Read};
+use std::io::{self, IsTerminal, Read, Write as _};
 use std::net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr};
 use std::path::PathBuf;
 use std::process;
@@ -28,8 +28,10 @@ use std::sync::Arc;
 
 use anyhow::{anyhow, Context, Result};
 use cookie_store::{CookieStore, RawCookie};
+use flate2::write::ZlibEncoder;
+use hyper::header::CONTENT_ENCODING;
 use redirect::RedirectFollower;
-use reqwest::blocking::Client;
+use reqwest::blocking::{Body as ReqwestBody, Client};
 use reqwest::header::{
     HeaderValue, ACCEPT, ACCEPT_ENCODING, CONNECTION, CONTENT_TYPE, COOKIE, RANGE, USER_AGENT,
 };
@@ -46,7 +48,6 @@ use crate::printer::Printer;
 use crate::request_items::{Body, FORM_CONTENT_TYPE, JSON_ACCEPT, JSON_CONTENT_TYPE};
 use crate::session::Session;
 use crate::utils::{test_mode, test_pretend_term, url_with_query};
-use crate::vendored::reqwest_cookie_store;
 
 #[cfg(not(any(feature = "native-tls", feature = "rustls")))]
 compile_error!("Either native-tls or rustls feature must be enabled!");
@@ -101,6 +102,11 @@ fn main() {
 }
 
 fn run(args: Cli) -> Result<i32> {
+    if let Some(generate) = args.generate {
+        generation::generate(&args.bin_name, generate);
+        return Ok(0);
+    }
+
     if args.curl {
         to_curl::print_curl_translation(args)?;
         return Ok(0);
@@ -504,6 +510,25 @@ fn run(args: Cli) -> Result<i32> {
 
         let mut request = request_builder.headers(headers).build()?;
 
+        if args.compress >= 1 {
+            if request.headers().contains_key(CONTENT_ENCODING) {
+                // HTTPie overrides the original Content-Encoding header in this case
+                log::warn!("--compress can't be used with a 'Content-Encoding:' header. --compress will be disabled.");
+            } else if let Some(body) = request.body_mut() {
+                // TODO: Compress file body (File) without buffering
+                let body_bytes = body.buffer()?;
+                let mut encoder = ZlibEncoder::new(Vec::new(), Default::default());
+                encoder.write_all(body_bytes)?;
+                let output = encoder.finish()?;
+                if output.len() < body_bytes.len() || args.compress >= 2 {
+                    *body = ReqwestBody::from(output);
+                    request
+                        .headers_mut()
+                        .insert(CONTENT_ENCODING, HeaderValue::from_static("deflate"));
+                }
+            }
+        }
+
         for header in &headers_to_unset {
             request.headers_mut().remove(header);
         }
