@@ -281,7 +281,7 @@ impl Session {
             Cookies::Map(_) => unreachable!(),
             Cookies::List(cookies) => cookies.iter().map(|cookie| {
                 let mut cookie_builder =
-                    cookie_store::RawCookie::build(cookie.name.clone(), cookie.value.clone());
+                    cookie_store::RawCookie::build((cookie.name.clone(), cookie.value.clone()));
 
                 if let Some(expires) = cookie.expires {
                     cookie_builder =
@@ -305,7 +305,7 @@ impl Session {
                 }
 
                 Ok(cookie_store::Cookie::try_from_raw_cookie(
-                    &cookie_builder.finish(),
+                    &cookie_builder.into(),
                     &cookie_url,
                 )?)
             }),
@@ -336,7 +336,7 @@ impl Session {
                     .expires()
                     .and_then(|v| v.datetime())
                     .map(|v| v.unix_timestamp()),
-                path: cookie.path().map(Into::into),
+                path: Some(cookie.path.to_string()),
                 secure: cookie.secure(),
                 domain: domain.map(Into::into),
             });
